@@ -1,7 +1,7 @@
 use crate::common::rand_string;
 use crate::{Config, ContainerConfig, Server};
 use derive_builder::Builder;
-use dockertest::{PullPolicy, Source};
+use dockertest::{waitfor, PullPolicy, Source};
 use std::collections::HashMap;
 
 const IMAGE: &str = "consul";
@@ -47,16 +47,22 @@ impl Config for ConsulServerConfig {
     fn into_composition(self) -> dockertest::Composition {
         let ports = vec![(PORT, self.port)];
 
+        let timeout = self.timeout;
+        let wait = Box::new(waitfor::MessageWait {
+            message: LOG_MSG.into(),
+            source: waitfor::MessageSource::Stdout,
+            timeout,
+        });
+
         ContainerConfig {
             args: self.args,
             env: self.env,
             handle: self.handle,
             name: IMAGE.into(),
             source: SOURCE,
-            timeout: self.timeout,
             version: self.version,
             ports: Some(ports),
-            wait_msg: Some(LOG_MSG.into()),
+            wait: Some(wait),
         }
         .into()
     }
@@ -66,7 +72,7 @@ impl Config for ConsulServerConfig {
     }
 }
 
-/// A running instane of a Consul server.
+/// A running instance of a Consul server.
 ///
 /// The server URL which is accessible from the local host can be found in
 /// `local_address`. Other running containers which need access to this server
