@@ -1,7 +1,7 @@
 use crate::common::rand_string;
 use crate::{Config, ContainerConfig, Server};
 use derive_builder::Builder;
-use dockertest::{PullPolicy, Source};
+use dockertest::{waitfor, PullPolicy, Source};
 use std::collections::HashMap;
 
 const IMAGE: &str = "vault";
@@ -11,7 +11,7 @@ const SOURCE: Source = Source::DockerHub(PullPolicy::IfNotPresent);
 
 /// Configuration for creating a Hashicorp Vault server.
 ///
-/// A token with root permisions will automatically be generated using the
+/// A token with root permissions will automatically be generated using the
 /// `token` field. If it's omitted the token will automatically be generated.
 ///
 /// By default the Vault server listens on port 8200 for HTTP requests. This
@@ -52,16 +52,22 @@ impl Config for VaultServerConfig {
         let mut env = self.env.clone();
         env.insert(String::from("VAULT_DEV_ROOT_TOKEN_ID"), self.token.clone());
 
+        let timeout = self.timeout;
+        let wait = Box::new(waitfor::MessageWait {
+            message: LOG_MSG.into(),
+            source: waitfor::MessageSource::Stdout,
+            timeout,
+        });
+
         ContainerConfig {
             args: self.args,
             env,
             handle: self.handle,
             name: IMAGE.into(),
             source: SOURCE,
-            timeout: self.timeout,
             version: self.version,
             ports: Some(ports),
-            wait_msg: Some(LOG_MSG.into()),
+            wait: Some(wait),
         }
         .into()
     }
@@ -71,7 +77,7 @@ impl Config for VaultServerConfig {
     }
 }
 
-/// A running instane of a Vault server.
+/// A running instance of a Vault server.
 ///
 /// The `token` field contains the root Vault token for the server. The server
 /// URL which is accessible from the local host can be found in `local_address`.
